#
# spec file for package kdb
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define sover 4

Name:           kdb
Version:        3.1.0
Release:        lp150.1.3
Summary:        Database Connectivity and Creation Framework
License:        LGPL-2.0
Group:          Productivity/Office/Other
Url:            http://community.kde.org/KDb
Source0:        https://download.kde.org/stable/%{name}/src/%{name}-%{version}.tar.xz
BuildRequires:  extra-cmake-modules
BuildRequires:  kconfig-devel
BuildRequires:  kcoreaddons-devel
BuildRequires:  libicu-devel
BuildRequires:  libmysqlclient-devel
BuildRequires:  libmysqld-devel
BuildRequires:  pkgconfig
BuildRequires:  postgresql-devel
BuildRequires:  sqlite3-devel
BuildRequires:  update-desktop-files
BuildRequires:  cmake(Qt5LinguistTools)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5Xml)
BuildRequires:  python-base
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
A database connectivity and creation framework for various database vendors

%package -n libKDb3-%{sover}
Summary:        The library for the Database Connectivity and Creation Framework
Group:          System/Libraries
Recommends:     %{name}-lang >= %{version}
Obsoletes:      calligra-kexi-mssql-driver < %{version}
Obsoletes:      calligra-kexi-xbase-driver < %{version}
Provides:       %{name} = %{version}

%description -n libKDb3-%{sover}
The library for the database connectivity and creation framework for various database vendors

%package devel
Summary:        Development package for kdb
Group:          Development/Libraries/KDE
Requires:       libKDb3-%{sover} = %{version}

%description devel
The development package for the database connectivity and creation framework

%package mysql-driver
Summary:        Database connectivity and creation framework - MySQL driver
Group:          Productivity/Office/Suite
Supplements:    packageand(libKDb3-%{sover}:mariadb)
Obsoletes:      calligra-kexi-mysql-driver < %{version}
Provides:       calligra-kexi-mysql-driver = %{version}

%description mysql-driver
This package contains the MySQL driver for the Database connectivity and creation framework

%package postgresql-driver
Summary:        Database connectivity and creation framework - PostgreSQL driver
Group:          Productivity/Office/Suite
Supplements:    packageand(libKDb3-%{sover}:postgresql)
Obsoletes:      calligra-kexi-postgresql-driver < %{version}
Provides:       calligra-kexi-postgresql-driver = %{version}

%description postgresql-driver
This package contains the PostgreSQL driver for the Database connectivity and creation framework

%package sqlite3-driver
Summary:        Database connectivity and creation framework - SQLite3 driver
Group:          Productivity/Office/Suite
Supplements:    packageand(libKDb3-%{sover}:sqlite3)
Obsoletes:      calligra-kexi-sqlite3-driver < %{version}
Provides:       calligra-kexi-sqlite3-driver = %{version}

%description sqlite3-driver
This package contains the SQLite3 driver for the Database connectivity and creation framework

%lang_package

%prep
%setup -q

%build
%cmake_kf5 -d build
%make_jobs

%install
  %kf5_makeinstall -C build
  %find_lang %{name} %{name}.lang --all-name --with-qt

%post -n libKDb3-%{sover} -p /sbin/ldconfig
%postun -n libKDb3-%{sover} -p /sbin/ldconfig

%files -n libKDb3-%{sover}
%defattr(-,root,root,-)
%doc COPYING.LIB
%{_libdir}/libKDb3.so.*

%files devel
%defattr(-,root,root,-)
%doc COPYING*
%{_includedir}/KDb3/
%{_libdir}/cmake/KDb3/
%{_libdir}/pkgconfig/KDb3.pc
%{_kf5_mkspecsdir}/qt_KDb3.pri
%{_libdir}/libKDb3.so

%files sqlite3-driver
%defattr(-,root,root,-)
%doc COPYING*
%{_bindir}/kdb3_sqlite3_dump
%dir %{_kf5_plugindir}/kdb3
%{_kf5_plugindir}/kdb3/kdb_sqlitedriver.so
%dir %{_kf5_plugindir}/kdb3/sqlite3
%{_kf5_plugindir}/kdb3/sqlite3/kdb_sqlite_icu.so

%files postgresql-driver
%defattr(-,root,root,-)
%doc COPYING*
%dir %{_kf5_plugindir}/kdb3
%{_kf5_plugindir}/kdb3/kdb_postgresqldriver.so

%files mysql-driver
%defattr(-,root,root,-)
%doc COPYING*
%dir %{_kf5_plugindir}/kdb3
%{_kf5_plugindir}/kdb3/kdb_mysqldriver.so

%files lang -f %{name}.lang
%defattr(-,root,root,-)

%changelog
* Tue Mar 20 2018 wbauer@tmo.at
- Update to 3.1.0:
  * General
    + Bump soname for the libraries to separate from incompatible
    3.0.x versions
    + Add Python 3 support for the buildsystem
  * API changes
    + See https://community.kde.org/Kexi/Releases/3.1.0_Changes for
    details
  * Bug fixes
    + Fix SQLite database compacting: canceling issue of the
    progress dialog and finalizing the compacting
    + Compacting: close the progress dialog also on error in
    SQLite3 processing; fix propagating error status to the GUI
    + SQLite driver: don't clear set of paths in
    extraSqliteExtensionPaths Connection property if exists
    + Add safer debug for large values
    + Fix issues because of using " quotes for identifiers in
    SQLite driver (kde#376052)
    + Query parsing: try harder to locate positions of table/table
    aliases
    + Connection dialog: make message handler optional, return
    result, accept on success
    + Fix KDbNativeStatementBuilder API: connection is always
    needed
    + Add COLLATION keywords when generated statements are native,
    otherwise KDbSQL string is invalid (kde#379447)
    + Fix generating of SQL statements if there are tables used
    having lookup fields based on queries (kde#385417)
    + Aesthetics: generate "SELECT FROM ..." statements with
    exactly one space after SELECT
    + Fix crash when generating "SELECT a.* FROM a, b" statements
    + Generate automatic ORDER BY only for native SQL statements
    + Raise SQL parse error when alias is duplicated for columns,
    e.g. "SELECT foo AS a, bar AS a FROM t"
    + Raise SQL parse error when alias is duplicated for tables,
    e.g. "SELECT * FROM foo AS a, bar AS a"
    + Expand scope of KDbTableSchemaChangeListener to allow
    registering queries for changes in table schema (kde#371896)
    + Properly unregister table from listeners before dropping
    + Setup query in connection: parsing failure can delete the
    query object so do not try to access it
    + Query schema: fix possible crashes - explicitly/properly
    remove query from connection's cache when needed
    + Query schema: fix memory leaks - remove internal expressions
  * Optimizations
    + Don't create temporary table schema object when checking for
    existence in createTable()
    + Don't create temporary table or query schema object when
    checking for existence object with empty name
  * Docs and examples
    + Update README-PACKAGERS doc to reflect naming and notes about
    compatibility
    + Enable creation of API docs QCH file during the build
* Wed Feb 28 2018 wbauer@tmo.at
- Add python-base build requirement to fix build in Leap 15
* Sat Aug 12 2017 wbauer@tmo.at
- Update to 3.0.2:
  * General
  - Fix possible issue: the WHERE condition can be lost while
    converting query to SQL. This can be seen in Kexi Query
    Designer.
  - Validate query and offer error message/description while
    setting or extending WHERE conditions
  - Fix WHERE conditions handling
  - Make query parameters also work in COLUMNS section. Kexi
    query parameters do not work in COLUMNS section, e.g. this
    won't work ('invalid query' error appears): SELECT [Param].
    The parameters work only in the WHERE section, e.g. SELECT
    123 WHERE [Param] = 1. (kde#348473)
  - Support queries such as "SELECT FROM table WHERE condition"
    for completeness
  * Buildsystem
  - Add detection for PostgreSQL 10
  - Improve information about recommended packages
    (for drivers, python, etc.)
  - Improve SQLite detection
  - FindMySQL script: for Windows use "ProgramFiles(x86)"
    environment variable to locate "Program Files (x86)" folder
    and find MySQL/MariaDB libs there
  - FindMySQL script: fix it if CMAKE_BUILD_TYPE is not
    specified (Windows)
  * Tests
  - Fix HeadersTest for paths containing spaces
  - Add tests related to query parameters to the parser test
* Fri Apr 28 2017 wbauer@tmo.at
- Fix the -lang package Recommends
* Tue Apr  4 2017 wbauer@tmo.at
- Update to 3.0.1.1:
  * General
  - Check result of closing database while testing connection
    (ConnectionTestThread)
  - Make it possible to set row source values for lookup column
    back to empty list
  - Fix setting properties for lookup column
    (record source related) (kde#371958)
  - Fix identifying table properties as related to lookup field
    (kde#371958)
  - Add safer debug for large values (internal in 3.0.1)
  * PostgreSQL support
  - Fix database cursors for PostgreSQL: remove use of
    uninitialized variable (kde#371331)
  - Fix error on repeated loading of "fuzzystrmatch" extension
    for the PostgreSQL driver
  * Buildsystem
  - Make it possible to find PostgreSQL 9.6
  - Improve support for Qt Translation catalogs
    (use ecm_install_po_files_as_qm macro)
  - Fix finding KDb config
    (use ecm_configure_package_config_file macro)
  - Add PROJECT_STABLE_VERSION_PATCH constant, extend logic for
    PROJECT_STABLE* constants
  - Improve discovery of PostgreSQL library on Windows
  - Improve searching for the MySQL driver build dependencies
  - SDC: initialize all variables in from-map constructors
    regardless of errors, add {} to conditions, improve spacing
  - Suppress warnings about duplicated drivers if
    KDB_NO_DUPLICATED_DRIVER_WARNINGS environment variable is set
- Replace KF5I18n BuildRequires with Qt5LinguistTools, that is used
  now for installing the translations
* Mon Jan 23 2017 wbauer@tmo.at
- Adjust the package Supplements, they were ineffective as there is
  no kdb package
* Wed Jan 11 2017 jengelh@inai.de
- RPM group fix
* Sun Jan  8 2017 tittiatcoke@gmail.com
-  Initial package based on version 3.0.0
